@@ -43,20 +43,14 @@
 #include <editeng/svxfont.hxx>
 #include <editeng/escpitem.hxx>
 
-// Minimum: Prozentwert fuers kernen
+// Minimum: Percentage of kernel
 #define MINKERNPERCENT 5
 
-// prop. Groesse der Kleinbuchstaben bei Kapitaelchen
-#define KAPITAELCHENPROP 80
-
 #ifndef REDUCEDSVXFONT
-    const sal_Unicode CH_BLANK = sal_Unicode(' ');  	// ' ' Leerzeichen
-    static sal_Char __READONLY_DATA sDoubleSpace[] = "  ";
+    const sal_Unicode CH_BLANK = sal_Unicode(' ');  // ' ' Space character
+    static sal_Char const sDoubleSpace[] = "  ";
 #endif
 
-/*************************************************************************
- *						class SvxFont
- *************************************************************************/
 
 SvxFont::SvxFont()
 {
@@ -75,10 +69,6 @@ SvxFont::SvxFont( const Font &rFont )
     eLang = LANGUAGE_SYSTEM;
 }
 
-/*************************************************************************
- *						class SvxFont: Copy-Ctor
- *************************************************************************/
-
 SvxFont::SvxFont( const SvxFont &rFont )
     : Font( rFont )
 {
@@ -89,12 +79,9 @@ SvxFont::SvxFont( const SvxFont &rFont )
     eLang = rFont.GetLanguage();
 }
 
-/*************************************************************************
- *				 static	SvxFont::DrawArrow
- *************************************************************************/
 
 void SvxFont::DrawArrow( OutputDevice &rOut, const Rectangle& rRect,
-    const Size& rSize, const Color& rCol, BOOL bLeft )
+    const Size& rSize, const Color& rCol, sal_Bool bLeft )
 {
     long nLeft = ( rRect.Left() + rRect.Right() - rSize.Width() )/ 2;
     long nRight = nLeft + rSize.Width();
@@ -129,15 +116,12 @@ void SvxFont::DrawArrow( OutputDevice &rOut, const Rectangle& rRect,
     rOut.SetFillColor( aOldFillColor );
 }
 
-/*************************************************************************
- *                      SvxFont::CalcCaseMap
- *************************************************************************/
 
 XubString SvxFont::CalcCaseMap( const XubString &rTxt ) const
 {
     if( !IsCaseMap() || !rTxt.Len() ) return rTxt;
     XubString aTxt( rTxt );
-    // Ich muss mir noch die Sprache besorgen
+    // I still have to get the language
     const LanguageType eLng = LANGUAGE_DONTKNOW == eLang
                             ? LANGUAGE_SYSTEM : eLang;
 
@@ -159,15 +143,15 @@ XubString SvxFont::CalcCaseMap( const XubString &rTxt ) const
         }
         case SVX_CASEMAP_TITEL:
         {
-            // Jeder Wortbeginn wird gross geschrieben,
-            // der Rest des Wortes wird unbesehen uebernommen.
-            // Bug: wenn das Attribut mitten im Wort beginnt.
-            BOOL bBlank = TRUE;
+            // Every beginning of a word is capitalized,  the rest of the word 
+            // is taken over as is. 
+            // Bug: if the attribute starts in the middle of the word.
+            sal_Bool bBlank = sal_True;
 
-            for( USHORT i = 0; i < aTxt.Len(); ++i )
+            for( sal_uInt16 i = 0; i < aTxt.Len(); ++i )
             {
                 if( sal_Unicode(' ') == aTxt.GetChar(i) || sal_Unicode('\t') == aTxt.GetChar(i) )
-                    bBlank = TRUE;
+                    bBlank = sal_True;
                 else
                 {
                     if( bBlank )
@@ -176,7 +160,7 @@ XubString SvxFont::CalcCaseMap( const XubString &rTxt ) const
                         aCharClass.toUpper( aTemp );
                         aTxt.Replace( i, 1, aTemp );
                     }
-                    bBlank = FALSE;
+                    bBlank = sal_False;
                 }
             }
             break;
@@ -191,16 +175,16 @@ XubString SvxFont::CalcCaseMap( const XubString &rTxt ) const
 }
 
 /*************************************************************************
- * Hier beginnen die Methoden, die im Writer nicht benutzt werden koennen,
- * deshalb kann man diesen Bereich durch setzen von REDUCEDSVXFONT ausklammern.
+* Starting form here are the methods that can not be used in Writer, 
+* so we put this section to be excluded by REDUCEDSVXFONT.
  *************************************************************************/
 #ifndef REDUCEDSVXFONT
 
 /*************************************************************************
  *						class SvxDoCapitals
- * die virtuelle Methode Do wird von SvxFont::DoOnCapitals abwechselnd mit
- * den "Gross-" und "Kleinbuchstaben"-Teilen aufgerufen.
- * Die Ableitungen von SvxDoCapitals erfuellen diese Methode mit Leben.
+ * The virtual Method Do si called by SvxFont::DoOnCapitals alternately 
+ * the uppercase and lowercase parts. The derivate of SvxDoCapitals fills
+ * this method with life.
  *************************************************************************/
 
 class SvxDoCapitals
@@ -217,11 +201,11 @@ public:
         : pOut(_pOut), rTxt(_rTxt), nIdx(_nIdx), nLen(_nLen)
         { }
 
-    virtual void DoSpace( const BOOL bDraw );
+    virtual void DoSpace( const sal_Bool bDraw );
     virtual void SetSpace();
     virtual void Do( const XubString &rTxt,
                      const xub_StrLen nIdx, const xub_StrLen nLen,
-                     const BOOL bUpper ) = 0;
+                     const sal_Bool bUpper ) = 0;
 
     inline OutputDevice *GetOut() { return pOut; }
     inline const XubString &GetTxt() const { return rTxt; }
@@ -229,17 +213,17 @@ public:
     xub_StrLen GetLen() const { return nLen; }
 };
 
-void SvxDoCapitals::DoSpace( const BOOL /*bDraw*/ ) { }
+void SvxDoCapitals::DoSpace( const sal_Bool /*bDraw*/ ) { }
 
 void SvxDoCapitals::SetSpace() { }
 
 void SvxDoCapitals::Do( const XubString &/*_rTxt*/, const xub_StrLen /*_nIdx*/,
-    const xub_StrLen /*_nLen*/, const BOOL /*bUpper*/ ) { }
+    const xub_StrLen /*_nLen*/, const sal_Bool /*bUpper*/ ) { }
 
 /*************************************************************************
  *					SvxFont::DoOnCapitals() const
- * zerlegt den String in Gross- und Kleinbuchstaben und ruft jeweils die
- * Methode SvxDoCapitals::Do( ) auf.
+ * Decomposes the String into uppercase and lowercase letters and then
+ * calls the method SvxDoCapitals::Do( ).
  *************************************************************************/
 
 void SvxFont::DoOnCapitals(SvxDoCapitals &rDo, const xub_StrLen nPartLen) const
@@ -249,9 +233,9 @@ void SvxFont::DoOnCapitals(SvxDoCapitals &rDo, const xub_StrLen nPartLen) const
     const xub_StrLen nLen = STRING_LEN == nPartLen ? rDo.GetLen() : nPartLen;
 
     const XubString aTxt( CalcCaseMap( rTxt ) );
-    const USHORT nTxtLen = Min( rTxt.Len(), nLen );
-    USHORT nPos = 0;
-    USHORT nOldPos = nPos;
+    const sal_uInt16 nTxtLen = Min( rTxt.Len(), nLen );
+    sal_uInt16 nPos = 0;
+    sal_uInt16 nOldPos = nPos;
 
     // #108210#
     // Test if string length differ between original and CaseMapped
@@ -265,11 +249,11 @@ void SvxFont::DoOnCapitals(SvxDoCapitals &rDo, const xub_StrLen nPartLen) const
 
     while( nPos < nTxtLen )
     {
-        // Erst kommen die Upper-Chars dran
+        // first in turn are teh uppercase letters
 
-        // 4251: Es gibt Zeichen, die Upper _und_ Lower sind (z.B. das Blank).
-        // Solche Zweideutigkeiten fuehren ins Chaos, deswegen werden diese
-        // Zeichen der Menge Lower zugeordnet !
+        // There are characters that are both upper- and lower-case L (eg blank)
+        // Such ambiguities lead to chaos, this is why these characters are 
+        // allocated to the lowercase characters!
 
         while( nPos < nTxtLen )
         {
@@ -291,16 +275,16 @@ void SvxFont::DoOnCapitals(SvxDoCapitals &rDo, const xub_StrLen nPartLen) const
                 const XubString aSnippet(rTxt, nIdx + nOldPos, nPos-nOldPos);
                 XubString aNewText = CalcCaseMap(aSnippet);
                 
-                rDo.Do( aNewText, 0, aNewText.Len(), TRUE );
+                rDo.Do( aNewText, 0, aNewText.Len(), sal_True );
             }
             else
             {
-                rDo.Do( aTxt, nIdx + nOldPos, nPos-nOldPos, TRUE );
+                rDo.Do( aTxt, nIdx + nOldPos, nPos-nOldPos, sal_True );
             }
 
             nOldPos = nPos;
         }
-        // Nun werden die Lower-Chars verarbeitet (ohne Blanks)
+        // Now the lowercase are processed (without blanks)
         while( nPos < nTxtLen )
         {
             sal_uInt32	nCharacterType = aCharClass.getCharacterType( aCharString, 0 );
@@ -321,22 +305,22 @@ void SvxFont::DoOnCapitals(SvxDoCapitals &rDo, const xub_StrLen nPartLen) const
                 const XubString aSnippet(rTxt, nIdx + nOldPos, nPos - nOldPos);
                 XubString aNewText = CalcCaseMap(aSnippet);
                 
-                rDo.Do( aNewText, 0, aNewText.Len(), FALSE );
+                rDo.Do( aNewText, 0, aNewText.Len(), sal_False );
             }
             else
             {
-                rDo.Do( aTxt, nIdx + nOldPos, nPos-nOldPos, FALSE );
+                rDo.Do( aTxt, nIdx + nOldPos, nPos-nOldPos, sal_False );
             }
 
             nOldPos = nPos;
         }
-        // Nun werden die Blanks verarbeitet
+        // Now the blanks are<processed
         while( nPos < nTxtLen && CH_BLANK == aCharString && ++nPos < nTxtLen )
             aCharString = rTxt.GetChar( nPos + nIdx );
 
         if( nOldPos != nPos )
         {
-            rDo.DoSpace( FALSE );
+            rDo.DoSpace( sal_False );
             
             if(bCaseMapLengthDiffers)
             {
@@ -346,23 +330,20 @@ void SvxFont::DoOnCapitals(SvxDoCapitals &rDo, const xub_StrLen nPartLen) const
                 const XubString aSnippet(rTxt, nIdx + nOldPos, nPos - nOldPos);
                 XubString aNewText = CalcCaseMap(aSnippet);
                 
-                rDo.Do( aNewText, 0, aNewText.Len(), FALSE );
+                rDo.Do( aNewText, 0, aNewText.Len(), sal_False );
             }
             else
             {
-                rDo.Do( aTxt, nIdx + nOldPos, nPos - nOldPos, FALSE );
+                rDo.Do( aTxt, nIdx + nOldPos, nPos - nOldPos, sal_False );
             }
 
             nOldPos = nPos;
             rDo.SetSpace();
         }
     }
-    rDo.DoSpace( TRUE );
+    rDo.DoSpace( sal_True );
 }
 
-/**************************************************************************
- *					  SvxFont::SetPhysFont()
- *************************************************************************/
 
 void SvxFont::SetPhysFont( OutputDevice *pOut ) const
 {
@@ -383,9 +364,6 @@ void SvxFont::SetPhysFont( OutputDevice *pOut ) const
     }
 }
 
-/*************************************************************************
- *					  SvxFont::ChgPhysFont()
- *************************************************************************/
 
 Font SvxFont::ChgPhysFont( OutputDevice *pOut ) const
 {
@@ -394,9 +372,6 @@ Font SvxFont::ChgPhysFont( OutputDevice *pOut ) const
     return aOldFont;
 }
 
-/*************************************************************************
- *					  SvxFont::GetPhysTxtSize()
- *************************************************************************/
 
 Size SvxFont::GetPhysTxtSize( const OutputDevice *pOut, const XubString &rTxt,
                          const xub_StrLen nIdx, const xub_StrLen nLen ) const
@@ -457,7 +432,7 @@ Size SvxFont::GetPhysTxtSize( const OutputDevice *pOut, const XubString &rTxt )
 }
 
 Size SvxFont::QuickGetTextSize( const OutputDevice *pOut, const XubString &rTxt,
-                         const USHORT nIdx, const USHORT nLen, sal_Int32* pDXArray ) const
+                         const sal_uInt16 nIdx, const sal_uInt16 nLen, sal_Int32* pDXArray ) const
 {
     if ( !IsCaseMap() && !IsKern() )
         return Size( pOut->GetTextArray( rTxt, pDXArray, nIdx, nLen ),
@@ -479,22 +454,19 @@ Size SvxFont::QuickGetTextSize( const OutputDevice *pOut, const XubString &rTxt,
         {
             for ( xub_StrLen i = 0; i < nLen; i++ )
                 pDXArray[i] += ( (i+1) * long( nKern ) );
-            // Der letzte ist um ein nKern zu gross:
+            // The last one is a nKern too big:
             pDXArray[nLen-1] -= nKern;
         }
     }
     return aTxtSize;
 }
 
-/*************************************************************************
- *					  SvxFont::GetTxtSize()
- *************************************************************************/
 
 Size SvxFont::GetTxtSize( const OutputDevice *pOut, const XubString &rTxt,
                          const xub_StrLen nIdx, const xub_StrLen nLen )
 {
     xub_StrLen nTmp = nLen;
-    if ( nTmp == STRING_LEN )	// schon initialisiert?
+    if ( nTmp == STRING_LEN )	// already initialized?
         nTmp = rTxt.Len();
     Font aOldFont( ChgPhysFont((OutputDevice *)pOut) );
     Size aTxtSize;
@@ -507,9 +479,6 @@ Size SvxFont::GetTxtSize( const OutputDevice *pOut, const XubString &rTxt,
     return aTxtSize;
 }
 
-/*************************************************************************
- *					  SvxFont::DrawText()
- *************************************************************************/
 
 void SvxFont::DrawText( OutputDevice *pOut,
                const Point &rPos, const XubString &rTxt,
@@ -517,7 +486,7 @@ void SvxFont::DrawText( OutputDevice *pOut,
 {
     if( !nLen || !rTxt.Len() )	return;
     xub_StrLen nTmp = nLen;
-    if ( nTmp == STRING_LEN )	// schon initialisiert?
+    if ( nTmp == STRING_LEN )	// already initialized?
         nTmp = rTxt.Len();
     Point aPos( rPos );
     if ( nEsc )
@@ -546,7 +515,7 @@ void SvxFont::QuickDrawText( OutputDevice *pOut,
     const Point &rPos, const XubString &rTxt,
     const xub_StrLen nIdx, const xub_StrLen nLen, const sal_Int32* pDXArray ) const
 {
-    // Font muss ins OutputDevice selektiert sein...
+    // Font has to be selected in OutputDevice...
     if ( !IsCaseMap() && !IsCapital() && !IsKern() && !IsEsc() )
     {
         pOut->DrawTextArray( rPos, rTxt, pDXArray, nIdx, nLen );
@@ -569,7 +538,7 @@ void SvxFont::QuickDrawText( OutputDevice *pOut,
 
     if( IsCapital() )
     {
-        DBG_ASSERT( !pDXArray, "DrawCapital nicht fuer TextArray!" );
+        DBG_ASSERT( !pDXArray, "DrawCapital not for TextArray!" );
         DrawCapital( pOut, aPos, rTxt, nIdx, nLen );
     }
     else
@@ -593,7 +562,6 @@ void SvxFont::QuickDrawText( OutputDevice *pOut,
     }
 }
 
-// -----------------------------------------------------------------------
 
 void SvxFont::DrawPrev( OutputDevice *pOut, Printer* pPrinter,
                         const Point &rPos, const XubString &rTxt,
@@ -603,7 +571,7 @@ void SvxFont::DrawPrev( OutputDevice *pOut, Printer* pPrinter,
         return;
     xub_StrLen nTmp = nLen;
 
-    if ( nTmp == STRING_LEN )	// schon initialisiert?
+    if ( nTmp == STRING_LEN )	// already initialized?
         nTmp = rTxt.Len();
     Point aPos( rPos );
 
@@ -655,7 +623,6 @@ void SvxFont::DrawPrev( OutputDevice *pOut, Printer* pPrinter,
     pPrinter->SetFont( aOldPrnFont );
 }
 
-// -----------------------------------------------------------------------
 
 SvxFont& SvxFont::operator=( const Font& rFont )
 {
@@ -674,13 +641,6 @@ SvxFont& SvxFont::operator=( const SvxFont& rFont )
     return *this;
 }
 
-
-/*************************************************************************
- *					  class SvxDoGetCapitalSize
- * wird von SvxFont::GetCapitalSize() zur Berechnung der TxtSize bei
- * eingestellten Kapitaelchen benutzt.
- *************************************************************************/
-
 class SvxDoGetCapitalSize : public SvxDoCapitals
 {
 protected:
@@ -697,19 +657,19 @@ public:
             { }
 
     virtual void Do( const XubString &rTxt, const xub_StrLen nIdx,
-                     const xub_StrLen nLen, const BOOL bUpper );
+                     const xub_StrLen nLen, const sal_Bool bUpper );
 
     inline const Size &GetSize() const { return aTxtSize; };
 };
 
 void SvxDoGetCapitalSize::Do( const XubString &_rTxt, const xub_StrLen _nIdx,
-                              const xub_StrLen _nLen, const BOOL bUpper )
+                              const xub_StrLen _nLen, const sal_Bool bUpper )
 {
     Size aPartSize;
     if ( !bUpper )
     {
-        BYTE nProp = pFont->GetPropr();
-        pFont->SetProprRel( KAPITAELCHENPROP );
+        sal_uInt8 nProp = pFont->GetPropr();
+        pFont->SetProprRel( SMALL_CAPS_PERCENTAGE );
         pFont->SetPhysFont( pOut );
         aPartSize.setWidth( pOut->GetTextWidth( _rTxt, _nIdx, _nLen ) );
         aPartSize.setHeight( pOut->GetTextHeight() );
@@ -726,11 +686,6 @@ void SvxDoGetCapitalSize::Do( const XubString &_rTxt, const xub_StrLen _nIdx,
     aTxtSize.Width() += ( _nLen * long( nKern ) );
 }
 
-/*************************************************************************
- *					  SvxFont::GetCapitalSize()
- * berechnet TxtSize, wenn Kapitaelchen eingestellt sind.
- *************************************************************************/
-
 Size SvxFont::GetCapitalSize( const OutputDevice *pOut, const XubString &rTxt,
                              const xub_StrLen nIdx, const xub_StrLen nLen) const
 {
@@ -748,11 +703,6 @@ Size SvxFont::GetCapitalSize( const OutputDevice *pOut, const XubString &rTxt,
     return aTxtSize;
 }
 
-/*************************************************************************
- *					   class SvxDoDrawCapital
- * wird von SvxFont::DrawCapital zur Ausgabe von Kapitaelchen benutzt.
- *************************************************************************/
-
 class SvxDoDrawCapital : public SvxDoCapitals
 {
 protected:
@@ -770,23 +720,23 @@ public:
           aSpacePos( rPos ),
           nKern( nKrn )
         { }
-    virtual void DoSpace( const BOOL bDraw );
+    virtual void DoSpace( const sal_Bool bDraw );
     virtual void SetSpace();
     virtual void Do( const XubString &rTxt, const xub_StrLen nIdx,
-                     const xub_StrLen nLen, const BOOL bUpper );
+                     const xub_StrLen nLen, const sal_Bool bUpper );
 };
 
-void SvxDoDrawCapital::DoSpace( const BOOL bDraw )
+void SvxDoDrawCapital::DoSpace( const sal_Bool bDraw )
 {
     if ( bDraw || pFont->IsWordLineMode() )
     {
-        USHORT nDiff = (USHORT)(aPos.X() - aSpacePos.X());
+        sal_uInt16 nDiff = (sal_uInt16)(aPos.X() - aSpacePos.X());
         if ( nDiff )
         {
-            BOOL bWordWise = pFont->IsWordLineMode();
-            BOOL bTrans = pFont->IsTransparent();
-            pFont->SetWordLineMode( FALSE );
-            pFont->SetTransparent( TRUE );
+            sal_Bool bWordWise = pFont->IsWordLineMode();
+            sal_Bool bTrans = pFont->IsTransparent();
+            pFont->SetWordLineMode( sal_False );
+            pFont->SetTransparent( sal_True );
             pFont->SetPhysFont( pOut );
             pOut->DrawStretchText( aSpacePos, nDiff, XubString( sDoubleSpace,
                             RTL_TEXTENCODING_MS_1252 ), 0, 2 );
@@ -804,12 +754,12 @@ void SvxDoDrawCapital::SetSpace()
 }
 
 void SvxDoDrawCapital::Do( const XubString &_rTxt, const xub_StrLen _nIdx,
-                           const xub_StrLen _nLen, const BOOL bUpper)
+                           const xub_StrLen _nLen, const sal_Bool bUpper)
 {
-    BYTE nProp = 0;
+    sal_uInt8 nProp = 0;
     Size aPartSize;
 
-    // Einstellen der gewuenschten Fonts
+    // Set the desired font
     FontUnderline eUnder = pFont->GetUnderline();
     FontStrikeout eStrike = pFont->GetStrikeout();
     pFont->SetUnderline( UNDERLINE_NONE );
@@ -817,7 +767,7 @@ void SvxDoDrawCapital::Do( const XubString &_rTxt, const xub_StrLen _nIdx,
     if ( !bUpper )
     {
         nProp = pFont->GetPropr();
-        pFont->SetProprRel( KAPITAELCHENPROP );
+        pFont->SetProprRel( SMALL_CAPS_PERCENTAGE );
     }
     pFont->SetPhysFont( pOut );
 
@@ -831,7 +781,7 @@ void SvxDoDrawCapital::Do( const XubString &_rTxt, const xub_StrLen _nIdx,
     }
     pOut->DrawStretchText(aPos,nWidth-nKern,_rTxt,_nIdx,_nLen);
 
-    // Font restaurieren
+    // Restore Font
     pFont->SetUnderline( eUnder );
     pFont->SetStrikeout( eStrike );
     if ( !bUpper )
@@ -842,7 +792,7 @@ void SvxDoDrawCapital::Do( const XubString &_rTxt, const xub_StrLen _nIdx,
 }
 
 /*************************************************************************
- * SvxFont::DrawCapital() gibt Kapitaelchen aus.
+ * SvxFont::DrawCapital() draws the uppercase letter.
  *************************************************************************/
 
 void SvxFont::DrawCapital( OutputDevice *pOut,
