@@ -38,7 +38,7 @@
 #include <editeng/numitem.hxx>
 #include <svl/eitem.hxx>
 #include <vcl/svapp.hxx>
-#include <gallery.hxx>
+#include <svx/gallery.hxx>
 #include <svl/urihelper.hxx>
 #include <editeng/brshitem.hxx>
 #include <svl/intitem.hxx>
@@ -46,14 +46,14 @@
 #include <vcl/graph.hxx>
 #include <vcl/msgbox.hxx>
 #include <editeng/flstitem.hxx>
-#include <dlgutil.hxx>
+#include <svx/dlgutil.hxx>
 #ifndef _XTABLE_HXX //autogen
 
 #include <svx/xtable.hxx>
 #endif
-#include <drawitem.hxx>
-#include <numvset.hxx>
-#include <htmlmode.hxx>
+#include <svx/drawitem.hxx>
+#include <svx/numvset.hxx>
+#include <svx/htmlmode.hxx>
 #include <unotools/pathoptions.hxx>
 #include <svtools/ctrltool.hxx>
 #include <editeng/unolingu.hxx>
@@ -100,10 +100,7 @@ static const sal_Char cSuffix[] = "Suffix";
 static const sal_Char cBulletChar[] = "BulletChar";
 static const sal_Char cBulletFontName[] = "BulletFontName";
 
-/* -----------------28.10.98 08:32-------------------
- *
- * --------------------------------------------------*/
-// Die Auswahl an Bullets aus den StarSymbol
+// The selection of bullets from the star symbol
 static const sal_Unicode aBulletTypes[] =
 {
     0x2022,
@@ -118,7 +115,7 @@ static const sal_Unicode aBulletTypes[] =
 
 static Font& lcl_GetDefaultBulletFont()
 {
-    static BOOL bInit = 0;
+    static sal_Bool bInit = 0;
     static Font aDefBulletFont( UniString::CreateFromAscii(
                                 RTL_CONSTASCII_STRINGPARAM( "StarSymbol" ) ),
                                 String(), Size( 0, 14 ) );
@@ -128,8 +125,8 @@ static Font& lcl_GetDefaultBulletFont()
         aDefBulletFont.SetFamily( FAMILY_DONTKNOW );
         aDefBulletFont.SetPitch( PITCH_DONTKNOW );
         aDefBulletFont.SetWeight( WEIGHT_DONTKNOW );
-        aDefBulletFont.SetTransparent( TRUE );
-        bInit = TRUE;
+        aDefBulletFont.SetTransparent( sal_True );
+        bInit = sal_True;
     }
     return aDefBulletFont;
 }
@@ -155,7 +152,7 @@ static void lcl_PaintLevel(OutputDevice* pVDev, sal_Int16 nNumberingType,
 }
 void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
 {
-    static USHORT __READONLY_DATA aLinesArr[] =
+    static sal_uInt16 aLinesArr[] =
     {
         15, 10,
         20, 30,
@@ -175,7 +172,7 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
 
     OutputDevice*  pDev = rUDEvt.GetDevice();
     Rectangle aRect = rUDEvt.GetRect();
-    USHORT	nItemId = rUDEvt.GetItemId();
+    sal_uInt16	nItemId = rUDEvt.GetItemId();
     long nRectWidth = aRect.GetWidth();
     long nRectHeight = aRect.GetHeight();
     Size aRectSize(nRectWidth, aRect.GetHeight());
@@ -206,8 +203,8 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
 
     if(!pVDev)
     {
-        // Die Linien werden nur einmalig in das VirtualDevice gepainted
-        // nur die Gliederungspage bekommt es aktuell
+        // The lines are only one time in the virtual device, only the outline
+        // page is currently done        
         pVDev = new VirtualDevice(*pDev);
         pVDev->SetMapMode(pDev->GetMapMode());
         pVDev->EnableRTL( IsRTLEnabled() );
@@ -219,12 +216,12 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
         if(aBackColor == aLineColor)
             aLineColor.Invert();
         pVDev->SetLineColor(aLineColor);
-        // Linien nur einmalig Zeichnen
+        // Draw line only once
         if(nPageType != NUM_PAGETYPE_NUM)
         {
             Point aStart(aBLPos.X() + nRectWidth *25 / 100,0);
             Point aEnd(aBLPos.X() + nRectWidth * 9 / 10,0);
-            for( USHORT i = 11; i < 100; i += 33)
+            for( sal_uInt16 i = 11; i < 100; i += 33)
             {
                 aStart.Y() = aEnd.Y() = aBLPos.Y() + nRectHeight  * i / 100;
                 pVDev->DrawLine(aStart, aEnd);
@@ -236,15 +233,15 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
     pDev->DrawOutDev(	aRect.TopLeft(), aRectSize,
                         aOrgRect.TopLeft(), aRectSize,
                         *pVDev );
-    // jetzt kommt der Text
+    // Now comes the text
     const OUString sValue(C2U(cValue));
     if( NUM_PAGETYPE_SINGLENUM == nPageType ||
             NUM_PAGETYPE_BULLET == nPageType )
     {
         Point aStart(aBLPos.X() + nRectWidth / 9,0);
-        for( USHORT i = 0; i < 3; i++ )
+        for( sal_uInt16 i = 0; i < 3; i++ )
         {
-            USHORT nY = 11 + i * 33;
+            sal_uInt16 nY = 11 + i * 33;
             aStart.Y() = aBLPos.Y() + nRectHeight  * nY / 100;
             String sText;
             if(nPageType == NUM_PAGETYPE_BULLET)
@@ -268,10 +265,10 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
                     }
                     catch(Exception&)
                     {
-                        DBG_ERROR("Exception in DefaultNumberingProvider::makeNumberingString");
+                        OSL_FAIL("Exception in DefaultNumberingProvider::makeNumberingString");
                     }
                 }
-                // knapp neben dem linken Rand beginnen
+                // start just next to the left edge
                 aStart.X() = aBLPos.X() + 2;
                 aStart.Y() -= pDev->GetTextHeight()/2;
             }
@@ -340,7 +337,7 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
                     }
                     catch(Exception&)
                     {
-                        DBG_ERROR("Exception in DefaultNumberingProvider::makeNumberingString");
+                        OSL_FAIL("Exception in DefaultNumberingProvider::makeNumberingString");
                     }
 
                     aLeft.Y() -= (pDev->GetTextHeight()/2);
@@ -388,7 +385,7 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
                     }
 
                     long nLineTop = nStartY + nRectHeight * aLinesArr[2 * i + 1]/100 ;
-                    Point aLineLeft(aLeft.X() /*+ nStartX + nRectWidth * aLinesArr[2 * i]/ 100*/, nLineTop );
+                    Point aLineLeft(aLeft.X(), nLineTop );
                     Point aLineRight(nStartX + nRectWidth * 90 /100, nLineTop );
                     pVDev->DrawLine(aLineLeft,	aLineRight);
                 }
@@ -397,10 +394,10 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
 #ifdef DBG_UTIL
             catch(Exception&)
             {
-                static sal_Bool bAssert = FALSE;
+                static sal_Bool bAssert = sal_False;
                 if(!bAssert)
                 {
-                    DBG_ERROR("exception in ::UserDraw");
+                    OSL_FAIL("exception in ::UserDraw");
                     bAssert = sal_True;
                 }
             }
@@ -419,18 +416,13 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
     pDev->SetLineColor(aOldColor);
 }
 
-/**************************************************************************/
-/*                                                                        */
-/*                                                                        */
-/**************************************************************************/
-
-SvxNumValueSet::SvxNumValueSet( Window* pParent, const ResId& rResId, USHORT nType ) :
+SvxNumValueSet::SvxNumValueSet( Window* pParent, const ResId& rResId, sal_uInt16 nType ) :
 
     ValueSet( pParent, rResId ),
 
     aLineColor  ( COL_LIGHTGRAY ),
     nPageType   ( nType ),
-    bHTMLMode   ( FALSE ),
+    bHTMLMode   ( sal_False ),
     pVDev       ( NULL )
 {
     SetColCount( 4 );
@@ -438,7 +430,7 @@ SvxNumValueSet::SvxNumValueSet( Window* pParent, const ResId& rResId, USHORT nTy
     SetStyle( GetStyle() | WB_ITEMBORDER | WB_DOUBLEBORDER );
     if(NUM_PAGETYPE_BULLET == nType)
     {
-        for	( USHORT i = 0; i < 8; i++ )
+        for	( sal_uInt16 i = 0; i < 8; i++ )
         {
             InsertItem( i + 1, i );
             SetItemText( i + 1, SVX_RESSTR( RID_SVXSTR_BULLET_DESCRIPTIONS + i ) );
@@ -446,17 +438,11 @@ SvxNumValueSet::SvxNumValueSet( Window* pParent, const ResId& rResId, USHORT nTy
     }
 }
 
-/*-----------------08.02.97 12.38-------------------
-
---------------------------------------------------*/
-
- SvxNumValueSet::~SvxNumValueSet()
+SvxNumValueSet::~SvxNumValueSet()
 {
     delete pVDev;
 }
-/* -----------------------------30.01.01 16:24--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SvxNumValueSet::SetNumberingSettings(
     const Sequence<Sequence<PropertyValue> >& aNum,
     Reference<XNumberingFormatter>& xFormat,
@@ -467,16 +453,14 @@ void SvxNumValueSet::SetNumberingSettings(
     aLocale = rLocale;
     if(aNum.getLength() > 8)
             SetStyle( GetStyle()|WB_VSCROLL);
-    for ( USHORT i = 0; i < aNum.getLength(); i++ )
+    for ( sal_uInt16 i = 0; i < aNum.getLength(); i++ )
     {
             InsertItem( i + 1, i );
             if( i < 8 )
                 SetItemText( i + 1, SVX_RESSTR( RID_SVXSTR_SINGLENUM_DESCRIPTIONS + i ));
     }
 }
-/* -----------------------------31.01.01 09:50--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SvxNumValueSet::SetOutlineNumberingSettings(
             Sequence<Reference<XIndexAccess> >& rOutline,
             Reference<XNumberingFormatter>& xFormat,
@@ -495,11 +479,10 @@ void SvxNumValueSet::SetOutlineNumberingSettings(
     }
 }
 
-SvxBmpNumValueSet::SvxBmpNumValueSet( Window* pParent, const ResId& rResId/*, const List& rStrNames*/ ) :
+SvxBmpNumValueSet::SvxBmpNumValueSet( Window* pParent, const ResId& rResId ) :
 
     SvxNumValueSet( pParent, rResId, NUM_PAGETYPE_BMP ),
-//    rStrList    ( rStrNames ),
-    bGrfNotFound( FALSE )
+    bGrfNotFound( sal_False )
 
 {
     GalleryExplorer::BeginLocking(GALLERY_THEME_BULLETS);
@@ -509,26 +492,19 @@ SvxBmpNumValueSet::SvxBmpNumValueSet( Window* pParent, const ResId& rResId/*, co
     aFormatTimer.SetTimeoutHdl(LINK(this, SvxBmpNumValueSet, FormatHdl_Impl));
 }
 
-/*-----------------13.02.97 09.41-------------------
-
---------------------------------------------------*/
-
- SvxBmpNumValueSet::~SvxBmpNumValueSet()
+SvxBmpNumValueSet::~SvxBmpNumValueSet()
 {
     GalleryExplorer::EndLocking(GALLERY_THEME_BULLETS);
     aFormatTimer.Stop();
 }
-/*-----------------13.02.97 09.41-------------------
 
---------------------------------------------------*/
-
-void   	SvxBmpNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
+void SvxBmpNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
 {
     SvxNumValueSet::UserDraw(rUDEvt);
 
     Rectangle aRect = rUDEvt.GetRect();
     OutputDevice*  pDev = rUDEvt.GetDevice();
-    USHORT	nItemId = rUDEvt.GetItemId();
+    sal_uInt16	nItemId = rUDEvt.GetItemId();
     Point aBLPos = aRect.TopLeft();
 
     int nRectHeight = aRect.GetHeight();
@@ -538,30 +514,26 @@ void   	SvxBmpNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
     if(!GalleryExplorer::GetGraphicObj( GALLERY_THEME_BULLETS, nItemId - 1,
                         &aGraphic, NULL))
     {
-        bGrfNotFound = TRUE;
+        bGrfNotFound = sal_True;
     }
     else
     {
         Point aPos(aBLPos.X() + 5, 0);
-        for( USHORT i = 0; i < 3; i++ )
+        for( sal_uInt16 i = 0; i < 3; i++ )
         {
-            USHORT nY = 11 + i * 33;
+            sal_uInt16 nY = 11 + i * 33;
             aPos.Y() = aBLPos.Y() + nRectHeight  * nY / 100;
             aGraphic.Draw( pDev, aPos, aSize );
         }
     }
 }
 
-/*-----------------14.02.97 07.34-------------------
-
---------------------------------------------------*/
-
 IMPL_LINK(SvxBmpNumValueSet, FormatHdl_Impl, Timer*, EMPTYARG)
 {
-    // nur, wenn eine Grafik nicht da war, muss formatiert werden
+    // only when a graphics was not there, it needs to be formatted
     if(bGrfNotFound)
     {
-        bGrfNotFound = FALSE;
+        bGrfNotFound = sal_False;
         Format();
     }
     Invalidate();
